#!/bin/bash
# 一键安装 Siproxd 和配置
set -e
echo "Installing Siproxd files..."
# 复制二进制、配置和插件
sudo cp -r usr/local/* /usr/local/
# 复制 systemd 服务文件
sudo cp -r etc/systemd/system/siproxd.service /etc/systemd/system/ 2>/dev/null || {
    sudo bash -c 'cat > /etc/systemd/system/siproxd.service << EOF
[Unit]
Description=Siproxd SIP Proxy
After=network.target
[Service]
ExecStart=/usr/local/sbin/siproxd
Restart=always
User=nobody
Group=nogroup
[Install]
WantedBy=multi-user.target
EOF'
}
# 创建必要目录
sudo mkdir -p /var/lib/siproxd /var/run/siproxd /var/log
sudo cp -r var/lib/siproxd/* /var/lib/siproxd/ 2>/dev/null
sudo cp -r var/run/siproxd/* /var/run/siproxd/ 2>/dev/null
# 设置日志文件
sudo touch /var/log/siproxd.log
sudo chmod 666 /var/log/siproxd.log
sudo chown nobody:nogroup /var/log/siproxd.log
# 设置配置文件权限
sudo chown nobody:nogroup /usr/local/etc/siproxd_passwd.cfg
sudo chmod 600 /usr/local/etc/siproxd_passwd.cfg
sudo chown nobody:nogroup /usr/local/etc/siproxd.conf
sudo chmod 644 /usr/local/etc/siproxd.conf
# 复制 SIPp 测试脚本
mkdir -p ~/sipp
cp -r sipp/* ~/sipp/ 2>/dev/null
# 配置 systemd 服务
sudo systemctl daemon-reload
sudo systemctl enable siproxd
# 启动 Siproxd
sudo systemctl start siproxd
echo "Siproxd installed and started. Check status with: sudo systemctl status siproxd"
echo "SIPp test scripts copied to ~/sipp/"
echo "Please edit /usr/local/etc/siproxd.conf to set network interfaces (e.g., if_inbound, if_outbound)."